module Config.Pages.Debate.Debate.Helpers exposing (..)

import Config.Data.Identity
    exposing
        ( pageNames
        , url
        )
import Config.Format.CardFormat exposing (..)
import Config.Format.Format
    exposing
        ( paragraphFontSize
        , paragraphSpacing
        )
import Config.Pages.Debate.Arguments.Helpers exposing (..)
import Config.Pages.Debate.Cuckery.Helpers exposing (..)
import Config.Pages.Debate.Debate.Pages.Arguments exposing (debateArguments)
import Config.Pages.Debate.Debate.Pages.Cucklist exposing (debateCuckList)
import Config.Pages.Debate.Debate.Pages.Gibberish exposing (debateGibberish)
import Config.Pages.Debate.Debate.Types exposing (..)
import Config.Pages.Debate.Gibberish.Helpers exposing (..)
import Config.Pages.Headers.Pages.Arguments exposing (argumentHeader)
import Config.Pages.Headers.Pages.CuckList exposing (cuckListHeader)
import Config.Pages.Headers.Pages.Gibberish exposing (gibberishHeader)
import Config.Style.Colour exposing (colourTheme)
import Config.Style.Glow
    exposing
        ( glowDeepDarkGrey
        , glowDeepDarkOrange
        )
import Config.Style.Transitions
    exposing
        ( hoverPageButtonDeepDarkOrange
        , transitionStyleSlow
        )
import Element as E exposing (..)
import Element.Background as B
import Element.Border as D
import Element.Font as F
import Html exposing (label)
import Html.Attributes as H


desktopDebateMaker : Debate -> Element msg
desktopDebateMaker debate =
    row
        topLevelBox
        [ cardImageMaker (debateImage debate) (debateLink debate)
        , cardMaker
            [ cardTitleMaker debate.debateTitle
            , cardFormatter
                [ cardContentSpacing
                    [ column
                        fieldSpacer
                        [ descriptionMaker debate ]
                    ]
                ]
            ]
        ]


mobileDebateMaker : Debate -> Element msg
mobileDebateMaker debate =
    row
        topLevelBox
        [ column [] []
        , cardMaker
            [ cardTitleMaker debate.debateTitle
            , cardFormatter
                [ cardContentSpacing
                    [ column
                        fieldSpacer
                        [ row [ width fill, spacing 10 ]
                            [ cardImageMakerMobile (debateImage debate) (debateLink debate)
                            , column
                                [ width fill ]
                                []
                            ]
                        ]
                    ]
                ]
            ]
        ]


debateImage :
    Debate
    ->
        { src : String
        , description : String
        }
debateImage debate =
    { src = "debate/" ++ debate.debateImage ++ ".png"
    , description = debate.debateTitle
    }


debateTitle : Debate -> String
debateTitle debate =
    debate.debateTitle


debateLink : Debate -> String
debateLink debate =
    debate.debateLink


descriptionMaker : Debate -> Element msg
descriptionMaker debate =
    column
        [ E.width fill
        , centerX
        , spacing 3
        ]
        [ row []
            [ paragraph
                ([ F.color colourTheme.textLightOrange
                 , paragraphSpacing
                 , paragraphFontSize
                 , F.bold
                 ]
                    ++ [ F.size 18
                       , E.width fill
                       ]
                )
                [ if
                    let
                        formatCuckCount =
                            [ F.regular
                            , F.size 16
                            ]
                    in
                    debate.debateTitle == "Arguments"
                  then
                    text "Inferences: "

                  else if debate.debateTitle == "Cucklist" then
                    text "Cucks: "

                  else if debate.debateTitle == "Gibberish" then
                    text "Gibberations: "

                  else
                    text ""
                , text (String.fromInt debate.debateCount)
                    |> el
                        [ F.color colourTheme.textLightGrey
                        , F.regular
                        , F.size 16
                        ]
                ]
            ]
        , row [ width fill ]
            [ paragraph
                [ F.color colourTheme.textLightGrey
                , paragraphSpacing
                , paragraphFontSize
                , spacing 3
                , F.regular
                , F.alignLeft
                , F.size 16
                ]
                [ text debate.debateDescription
                ]
            ]
        ]
