module Config.Pages.Debate.Gibberish.Domains.Normativity exposing (..)

import Config.Helpers.Converters exposing (formatName)
import Config.Pages.Debate.Gibberish.Types exposing (..)


normativityGibberish : Gibberish
normativityGibberish =
    let
        name =
            "Normativity"
    in
    { gibberishTitle = name
    , gibberishImage = formatName name
    , gibberishLink = "https://en.wikipedia.org/wiki/Normativity"
    , gibberishDescription = "Normativity refers to the phenomenon in human societies where certain actions or outcomes are designated as good, desirable, or permissible, while others are viewed as bad or undesirable. It encompasses the rules, standards, or norms that guide behaviors and judgments within a community, influencing what individuals ought to think and value. In philosophical contexts, normativity is often linked to moral and ethical considerations, shaping discussions about what is right or wrong."
    , gibberishTerms =
        [ { term = "Externalist Value"
          , strength = 0
          , explanation = SpecificExplanation "I take value to be a concept that's indexed to the assessment of at least one agent, so a notion such as \"externalist value\" just sounds like a contradiction."
          }
        , { term = "Irreducible Normativity"
          , strength = 5
          , explanation = SpecificExplanation "I typically don't really understand irreducibility language in philosophy. Most philosophers seem to just use it as a sort of profound-sounding placeholder for when their personal creativity for explanation runs dry. No idea what it's meant to mean here, though."
          }
        , { term = "Stance-Independent Normativity"
          , strength = 0
          , explanation = SpecificExplanation "I take norms to be semantically interchangeable with preferences, and I take preferences to be stance-dependent. As such, the notion of a stance-independent norm just sounds like gobbledy."
          }
        ]
    }
