module Pages.Services exposing (Model, Msg, page)

import Config.Data.Identity exposing (pageNames)
import Config.Format.Response
    exposing
        ( pageListDesktop
        , topLevelContainer
        )
import Config.Helpers.Viewport exposing (resetViewport)
import Config.Pages.Headers.Helpers exposing (headerMaker)
import Config.Pages.Headers.Pages.Services exposing (servicesHeader)
import Config.Pages.Services.Helpers exposing (..)
import Config.Pages.Services.Offerings.DebateAnalysis exposing (..)
import Config.Pages.Services.Offerings.DebateTutoring exposing (..)
import Config.Pages.Services.Offerings.ElmBuilds exposing (..)
import Config.Pages.Services.Offerings.NixBuilds exposing (..)
import Config.Pages.Services.Offerings.NutritionScience exposing (..)
import Config.Style.Colour as T exposing (..)
import Effect exposing (Effect)
import Element as E exposing (..)
import Layouts
import Page exposing (Page)
import Route exposing (Route)
import Shared exposing (..)
import View exposing (View)


page : Shared.Model -> Route () -> Page Model Msg
page shared route =
    Page.new
        { init = init
        , update = update
        , subscriptions = subscriptions
        , view = view shared
        }
        |> Page.withLayout toLayout


toLayout : Model -> Layouts.Layout Msg
toLayout model =
    Layouts.Navbar {}



-- INIT


type alias Model =
    {}


init : () -> ( Model, Effect Msg )
init () =
    ( {}
    , Effect.map
        (\_ -> NoOp)
        (Effect.sendCmd resetViewport)
    )



-- UPDATE


type Msg
    = NoOp


update : Msg -> Model -> ( Model, Effect Msg )
update msg model =
    case msg of
        NoOp ->
            ( model
            , Effect.none
            )



-- SUBSCRIPTIONS


subscriptions : Model -> Sub Msg
subscriptions model =
    Sub.none



-- VIEW


view : Shared.Model -> Model -> View Msg
view shared model =
    { title = pageNames.pageServices ++ " ( )"
    , attributes = []
    , element = servicesContainer shared.device
    }


servicesContainer : Device -> Element msg
servicesContainer device =
    topLevelContainer (servicesList device)


servicesList : Device -> Element msg
servicesList device =
    column
        (case ( device.class, device.orientation ) of
            _ ->
                pageListDesktop
        )
    <|
        List.concat
            [ List.map headerMaker
                [ servicesHeader ]
            , (case ( device.class, device.orientation ) of
                ( Phone, Portrait ) ->
                    List.map serviceMakerMobile

                ( Tablet, Portrait ) ->
                    List.map serviceMakerMobile

                _ ->
                    List.map serviceMaker
              )
                [ servicesDebateAnalysis
                , servicesDebateTutoring
                , servicesNutritionScience
                , servicesNixBuilds
                , servicesElmBuilds
                ]
            ]
